VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package conmet

Package {conmet}


Title: Construct Measurement Evaluation Tool
Version: 0.1.0
Description: With this package you can run 'ConMET' locally in R. 'ConMET' is an R-shiny application that facilitates performing and evaluating confirmatory factor analyses (CFAs) and is useful for running and reporting typical measurement models in applied psychology and management journals. 'ConMET' automatically creates, compares and summarizes CFA models. Most common fit indices (E.g., CFI and SRMR) are put in an overview table. ConMET also allows to test for common method variance. The application is particularly useful for teaching and instruction of measurement issues in survey research. The application uses the 'lavaan' package (Rosseel, 2012) to run CFAs.
Depends: R (≥ 3.5.0), shiny, shinydashboard
Imports: foreign, waiter, shinyWidgets, purrr, lavaan, summarytools, stringr, dplyr, Hmisc, semTools, openxlsx, DT
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-08-20 13:40:18 UTC; 68883lde
Author: Leander De Schutter ORCID iD [aut, cre]
Maintainer: Leander De Schutter <deschutter@rsm.nl>
Repository: CRAN
Date/Publication: 2021-08-21 09:40:09 UTC

Runs the Construct Measurement Evaluation Tool.

Description

'ConMET' is an R-shiny application that facilitates performing and evaluating confirmatory factor analyses (CFAs) and is useful for running and reporting typical measurement models in applied psychology and management journals. 'ConMET' automatically creates, compares and summarizes CFA models. Most common fit indices (E.g., CFI and SRMR) are put in an overview table. 'ConMET' also allows to test for common method variance. The application is particularly useful for teaching and instruction of measurement issues in survey research.
The application uses the cfa function from the 'lavaan' package (Rosseel, 2012) to run CFAs.

Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. URL https://www.jstatsoft.org/v48/i02/.

Usage

run_conmet()

Value

Runs the 'ConMET' shiny application.

Examples

if(interactive()){
library(conmet)
run_conmet()
}

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.